==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/zu/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Qinisekisa u-Bulk Susa amafa',
  'bulk_delete_help'	=> 'Buyekeza amafa wokususwa okuningi ngezansi. Uma usususiwe, la mafa angabuyiselwa, kodwa ngeke ahlanganiswe nanoma yimuphi abasebenzisi okwamanje abelwe wona.',
  'bulk_delete_warn'	=> 'Uzosusa: impahla ye-asethi_diza.',
	'bulk_update'		=> 'Ukuvuselela amafa we-Bulk',
	'bulk_update_help'	=> 'Leli fomu likuvumela ukuthi ubuyekeze amafa amaningi ngesikhathi esisodwa. Gcwalisa kuphela amasimu okudingayo ukuguqula. Noma yiziphi izinkambu ezishiywe zingenakushintshwa.',
	'bulk_update_warn'	=> 'Usuzohlela izakhiwo ze-asethi_impahla yamanani.',
    'checkedout_to'		=> 'Ikhiyiwe Kuzo',
    'checkout_date'		=> 'Usuku lokuhlola',
    'checkin_date'		=> 'Usuku lokuhlola',
    'checkout_to'		=> 'I-Checkout iya',
    'cost'				=> 'Izindleko zokuthenga',
    'create'			=> 'Dala i-Asset',
    'date'				=> 'Usuku lokuthenga',
    'depreciation'	    => 'Ukunciphisa',
    'depreciates_on'	=> 'Iyancipha',
    'default_location'	=> 'Indawo okuzenzakalelayo',
    'eol_date'			=> 'Usuku lwe-EOL',
    'eol_rate'			=> 'I-EOL Rate',
    'expected_checkin'  => 'Ilanga le-Checkin elilindelekile',
    'expires'			=> 'Iphelelwa yisikhathi',
    'fully_depreciated'	=> 'Ukunciphisa ngokuphelele',
    'help_checkout'		=> 'Uma ufisa ukwabela le mali ngaso leso sikhathi, khetha "Ukulungele Ukusebenzisa" kusuka kuhlu lokulunga ngenhla.',
    'mac_address'		=> 'Ikheli le-MAC',
    'manufacturer'		=> 'Umkhiqizi',
    'model'				=> 'Isibonelo',
    'months'			=> 'izinyanga',
    'name'				=> 'Igama lefa',
    'notes'				=> 'Amanothi',
    'order'				=> 'Inombolo Ye-oda',
    'qr'				=> 'Ikhodi ye-QR',
    'requestable'		=> 'Abasebenzisi bangase bacele le mali',
    'select_statustype'	=> 'Khetha uhlobo lomumo',
    'serial'			=> 'Serial',
    'status'			=> 'Isimo',
    'tag'				=> 'Ithegi lefa',
    'update'			=> 'Ukuvuselelwa kwefa',
    'warranty'			=> 'Iwaranti',
		'warranty_expires'		=> 'Warranty Expires',
    'years'				=> 'iminyaka',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/zu/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Qinisekisa u-Bulk Susa amafa',
  'bulk_delete_help'	=> 'Buyekeza amafa wokususwa okuningi ngezansi. Uma usususiwe, la mafa angabuyiselwa, kodwa ngeke ahlanganiswe nanoma yimuphi abasebenzisi okwamanje abelwe wona.',
  'bulk_delete_warn'	=> 'Uzosusa: impahla ye-asethi_diza.',
    'bulk_update'		=> 'Ukuvuselela amafa we-Bulk',
    'bulk_update_help'	=> 'Leli fomu likuvumela ukuthi ubuyekeze amafa amaningi ngesikhathi esisodwa. Gcwalisa kuphela amasimu okudingayo ukuguqula. Noma yiziphi izinkambu ezishiywe zingenakushintshwa.',
    'bulk_update_warn'	=> 'Usuzohlela izakhiwo ze-asethi_impahla yamanani.',
    'checkedout_to'		=> 'Ikhiyiwe Kuzo',
    'checkout_date'		=> 'Usuku lokuhlola',
    'checkin_date'		=> 'Usuku lokuhlola',
    'checkout_to'		=> 'I-Checkout iya',
    'cost'				=> 'Izindleko zokuthenga',
    'create'			=> 'Dala i-Asset',
    'date'				=> 'Usuku lokuthenga',
    'depreciation'	    => 'Ukunciphisa',
    'depreciates_on'	=> 'Iyancipha',
    'default_location'	=> 'Indawo okuzenzakalelayo',
    'eol_date'			=> 'Usuku lwe-EOL',
    'eol_rate'			=> 'I-EOL Rate',
    'expected_checkin'  => 'Ilanga le-Checkin elilindelekile',
    'expires'			=> 'Iphelelwa yisikhathi',
    'fully_depreciated'	=> 'Ukunciphisa ngokuphelele',
    'help_checkout'		=> 'Uma ufisa ukwabela le mali ngaso leso sikhathi, khetha "Ukulungele Ukusebenzisa" kusuka kuhlu lokulunga ngenhla.',
    'mac_address'		=> 'Ikheli le-MAC',
    'manufacturer'		=> 'Umkhiqizi',
    'model'				=> 'Isibonelo',
    'months'			=> 'izinyanga',
    'name'				=> 'Igama lefa',
    'notes'				=> 'Amanothi',
    'order'				=> 'Inombolo Ye-oda',
    'qr'				=> 'Ikhodi ye-QR',
    'requestable'		=> 'Abasebenzisi bangase bacele le mali',
    'select_statustype'	=> 'Khetha uhlobo lomumo',
    'serial'			=> 'Serial',
    'status'			=> 'Isimo',
    'tag'				=> 'Ithegi lefa',
    'update'			=> 'Ukuvuselelwa kwefa',
    'warranty'			=> 'Iwaranti',
        'warranty_expires'		=> 'Warranty Expires',
    'years'				=> 'iminyaka',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
